// Testing Boost.Iostreams with MinGW GCC 3.4.2
//
// Compile command:
// g++ boost_iostreams.cpp -I%BOOST_ROOT% -DBOOST_IOSTREAMS_NO_LIB -Wall -Wextra



#include <boost/iostreams/concepts.hpp>
#include <boost/iostreams/streambuf_facade.hpp>

#include <vector>
#include <iostream>
#include <algorithm>        // copy
#include <iterator>         // ostream_iterator



class vector_sink : public boost::io::sink
{
    public:
    
    vector_sink(std::vector<char>& vec) : m_vec(vec) { }
    
    void write(char const *str, std::streamsize size)
    {
        m_vec.insert(m_vec.end(), str, str + size);
    }
    
    
    private:
    
    std::vector<char>& m_vec;
};



int main()
{
    std::vector<char> vec;
    boost::io::streambuf_facade<vector_sink> out(vector_sink(vec));
    out << 123 << "foo";
    std::copy(
        vec.begin(), vec.end(), std::ostream_iterator<char>(std::cout, "\n"));
}
